Documentation
¶
Index ¶
Constants ¶
const LogstashTemplate = `` /* 1133-byte string literal not displayed */
const Template = `` /* 1132-byte string literal not displayed */
Variables ¶
var ErrFromElasticsearch = errors.New("elasticsearch reported an error")
var Templates = map[string]string{ "cypress": Template, "logstash": LogstashTemplate, }
Functions ¶
This section is empty.
Types ¶
type MockConnection ¶
type Plugin ¶
type Plugin struct {
Host string `description:"host:port of elasticsearch node"`
Index string `description:"fixed index to use if set"`
Prefix string `description:"index prefix to use with dated indices (cypress)"`
Logstash bool `description:"use logstash format indices"`
}
func (*Plugin) Description ¶
type Send ¶
type Send struct {
Host string `short:"H" long:"host" default:"localhost:9200" description:"Address of elasticsearch"`
Index string `short:"i" long:"index" description:"Store all messages in one index rather than date driven indexes"`
Prefix string `short:"p" long:"prefix" default:"cypress" description:"Prefix to apply to date driven indexes"`
Logstash bool `short:"l" long:"logstash" description:"Store messages like logstash does"`
// contains filtered or unexported fields
}
func (*Send) SetupTemplate ¶
Check and write an index template for the indexes used
Click to show internal directories.
Click to hide internal directories.